@@ -9,6 +9,7 @@ class S3ContainerMixin(object):
     _bucket_name: str
     _bucket_uri: str
     prefix: Optional[str]
+    uri: str
     _client: BaseClient
 
     def list_object_keys(self) -> List[str]:
@@ -33,7 +34,7 @@ class S3ContainerMixin(object):
                 object_keys.extend([f['Key'] for f in response['Contents']])
         return object_keys
 
-    def folder_uris(self, deep: bool = False) -> List[str]:
+    def folder_keys(self, deep: bool = False) -> List[str]:
         """
         Return the name of each folder in the container.
         """
@@ -41,14 +42,23 @@ class S3ContainerMixin(object):
             slashes = 0
         else:
             slashes = self.prefix.count('/')
-        folder_uris = []
+        folder_keys = []
         for object_key in self.list_object_keys():
             if object_key.endswith('/'):
                 if deep or object_key.count('/') == slashes + 1:
-                    folder_uris.append(object_key)
-        return folder_uris
+                    folder_keys.append(object_key)
+        return folder_keys
 
-    def file_uris(self, deep: bool = False) -> List[str]:
+    def folder_uris(self, deep: bool = False) -> List[str]:
+        """
+        Return the uri of each folder in the container.
+        """
+        return [
+            f'{self._bucket_uri}{folder_key}'
+            for folder_key in self.folder_keys(deep=deep)
+        ]
+
+    def file_keys(self, deep: bool = False) -> List[str]:
         """
         Return the name of each file in the container.
         """
@@ -56,15 +66,28 @@ class S3ContainerMixin(object):
             slashes = 0
         else:
             slashes = self.prefix.count('/')
-        file_uris = []
+        file_keys = []
         for object_key in self.list_object_keys():
             if not object_key.endswith('/'):
                 if deep or object_key.count('/') == slashes:
-                    file_uris.append(object_key)
-        return file_uris
+                    file_keys.append(object_key)
+        return file_keys
+
+    def file_uris(self, deep: bool = False) -> List[str]:
+        """
+        Return the uri of each folder in the container.
+        """
+        return [
+            f'{self._bucket_uri}{file_key}'
+            for file_key in self.file_keys(deep=deep)
+        ]
 
     def size(self) -> int:
         """
         Return the size of the bucket and its contents, in bytes.
         """
         raise NotImplementedError
+
+    def __repr__(self):
+
+        return self.uri
\ No newline at end of file
